pub enum LayoutAlgorithm {
None,
Inline,
InlineMeasure,
Block,
InlineBlock,
BlockMeasure,
Flex,
InlineFlex,
Grid,
InlineGrid,
}Expand description
The supported layout algorithms.
Variants
None
Used when the node has no layout, e.g. display: none.
Inline
Used when the node is an inline node.
display: inline does not guarantee this.
For example, if the parent node has display: flex,
this node will not be an inline node.
InlineMeasure
Used when the node measured as an inline node.
Block
Used when the node is a block node.
InlineBlock
Used when the node is an inline-block node.
BlockMeasure
Used when the node measured as a block node.
Flex
Used when the node is a flex container, e.g. display: flex.
InlineFlex
Used when the node is an inline-flex node.
Grid
Used when the node is a grid container, e.g. display: grid.
InlineGrid
Used when the node is an inline-grid node.