LayoutGridAuto

Struct LayoutGridAuto 

pub struct LayoutGridAuto<L: LengthNum, T: PartialEq + Clone = i32>(pub Vec<LayoutTrackSize<L, T>>);
CSS Grid 7.6: Implicit Track Sizing https://www.w3.org/TR/css-grid-1/#auto-tracks

The grid-auto-rows and grid-auto-columns properties specify the size of implicitly-created grid tracks.

Tuple Fields

0: Vec<LayoutTrackSize<L, T>>

Implementations

Source

impl<L: LengthNum, T: PartialEq + Clone> LayoutGridAuto<L, T>

pub fn get(&self, index: usize) -> LayoutTrackSize<L, T>

Get the track size for an implicit track at the given index. Cycles through the list if index exceeds the list length.

pub fn len(&self) -> usize

Get the number of track sizes in the list.

pub fn is_empty(&self) -> bool

Check if the list is empty.