InlineUnit

Trait InlineUnit 

pub trait InlineUnit<T: LayoutTreeNode> {
    type Env;

    // Required method
    fn new(
        env: &mut Self::Env,
        node: &T,
        result: MeasureResult<T::Length>,
    ) -> Self;
}
A helper type as the inline form of a tree node.

Required Associated Types

type Env

Some custom environment data.

Required Methods

fn new(env: &mut Self::Env, node: &T, result: MeasureResult<T::Length>) -> Self

Construct from a tree node with specified size and baseline information.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors